import { Injectable } from "@angular/core";
import { Observable } from "rxjs";
import { AutherService } from "@justbe-angular/jb-auther";
import { AuthDataHandlerService } from "./auth-data-handler.service";
import { AuthConfigurationsModel } from "../models/auth-configurations.model";
import { GetOtpInputParamsModel } from "@justbe-angular/jb-auther/models/get-otp-input-params.model";
import { LoginUsingOtpInputParamsModel } from "../models/login-using-otp-input-params";
import { GlobalsModel } from "../models/globals.model";
import { StoreService } from "@justbe-angular/jb-store";
var AuthService = (function () {
    function AuthService(autherService, authDataHandler, storeService) {
        this.autherService = autherService;
        this.authDataHandler = authDataHandler;
        this.storeService = storeService;
    }
    AuthService.prototype.setConfigurations = function (authconfigs) {
        this.authConfigs = AuthConfigurationsModel.build(authconfigs);
        this.autherService.setConfigurations({ endPoint: this.authConfigs.endPoint, type: this.authConfigs.type });
    };
    AuthService.prototype.getConfigurations = function () {
        return this.authConfigs;
    };
    AuthService.prototype.loginUsingOtp = function (loginUsingOtpInputParams) {
        loginUsingOtpInputParams = LoginUsingOtpInputParamsModel.build(loginUsingOtpInputParams);
        return this.autherService.loginUsingOtp(loginUsingOtpInputParams);
    };
    AuthService.prototype.getOtp = function (getOtpInputParams) {
        getOtpInputParams = GetOtpInputParamsModel.build(getOtpInputParams);
        return this.autherService.getOtp(getOtpInputParams);
    };
    AuthService.prototype.logout = function () {
        var _this = this;
        return new Observable(function (observer) {
            _this.autherService.jbLogout().subscribe(function (res) {
                _this.authDataHandler.clearData().subscribe(function (res) {
                    observer.next(200);
                    observer.complete();
                }, function (err) {
                    observer.error(500);
                });
            }, function (err) {
                observer.error(500);
            });
        });
    };
    AuthService.prototype.getAuthData = function () {
        return this.authDataHandler.getAuthData();
    };
    AuthService.prototype.setConfigs = function (globals) {
        globals = GlobalsModel.build(globals);
        this.autherService.setConfigs({
            api: globals.api
        });
        this.storeService.updateSubstore('AuthDataHandlerGlobals', globals);
    };
    AuthService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    AuthService.ctorParameters = function () { return [
        { type: AutherService, },
        { type: AuthDataHandlerService, },
        { type: StoreService, },
    ]; };
    return AuthService;
}());
export { AuthService };
//# sourceMappingURL=auth.service.js.map